![Specvizitor GUI](https://github.com/ivkram/specvizitor/blob/main/docs/screenshots/specvizitor_gui.png?raw=true "Specvizitor GUI")

## Installation

### Installing `specvizitor` using pip

Set up a local environment and run

        $ pip install specvizitor

### Installing `specvizitor` from source

1. Clone the public repository:

        $ git clone https://github.com/ivkram/specvizitor
        $ cd specvizitor

2. Set up a local environment and run

        $ pip install -e .

## Starting `specvizitor`
    
To start `specvizitor`, run this command in your terminal:    

    $ specvizitor

## License

`specvizitor` is licensed under a 3-clause BSD style license - see the [LICENSE.txt](https://github.com/ivkram/specvizitor/blob/main/LICENSE.txt) file.